@@ -12,6 +12,7 @@ enum PathSearchResult {
 	TOO_MANY_PATHS,
 	TOO_MANY_BRANCHES,
 	PATH_CONTAINS_CYCLE,
+	MAX_COST_EXCEEDED,
 	EXCEEDED_MEM_LIMIT,
 	NO_PATH
 };
@@ -21,6 +22,7 @@ const char* PathSearchResultLabel[] = {
 	"TOO_MANY_PATHS",
 	"TOO_MANY_BRANCHES",
 	"PATH_CONTAINS_CYCLE",
+	"MAX_COST_EXCEEDED",
 	"EXCEEDED_MEM_LIMIT",
 	"NO_PATH"
 };
